@@ -1,17 +1,41 @@
 
-elev.test <- function( y, x, test.value=0, data=NULL, alpha=0.05, method="SMA", V=matrix(0,2,2) )
+elev.test <- function( y, x, test.value=0, data=NULL, alpha=0.05, method="SMA", robust=FALSE, V=matrix(0,2,2) )
 {
-    if ( is.null(data)==FALSE )
-    {
-        attach(data)
-    }
+#     if ( is.null(data)==FALSE )
+#     {
+#         attach(data)
+#     }
 
+  
+  if(!is.null(data))
+    stop("'data' argument no longer supported.")
+  
+  
     iref <- ( is.na(x+y) == FALSE ) #to remove NA cases
     n    <- sum(iref)
     res.df <- n - 2
     fcrit  <- qf( 1-alpha, 1, res.df )
     dat    <- cbind( y[iref], x[iref] )
-    vr     <- ( var( dat ) - V )*( n - 1 )
+    if ( robust )
+    {
+		# get robust mean/var matrix:
+		q     <- pchisq(3,2)
+		S     <- huber.M(dat)
+		means <- S$loc
+		vr    <- ( S$cov - V) *(n-1)
+
+		# get robust.factors (multipliers on variance matrix):
+                rfac  <- robust.factor(dat,q)
+ 	        r.factor1 <- rfac[1]
+                r.factor2 <- rfac[2]
+    }
+    else
+    {
+      r.factor1 <- 1
+      r.factor2 <- 1 
+      means    <- apply(dat,2,mean)
+      vr <- ( var(dat) - V )*(n-1) 
+    }	
     r      <- vr[1,2]/( ( vr[1,1]*vr[2,2] )^0.5 )
 
     if ( (method==0) | (method=="OLS") )
@@ -35,16 +59,15 @@ elev.test <- function( y, x, test.value=0, data=NULL, alpha=0.05, method="SMA",
         var.b   <- 1 / ( var.res/var.fit + var.fit/var.res - 2)*( 1 + b^2 )^2 / res.df    # Use Fisher info
     }
 
-    means    <- apply(dat,2,mean)
     a        <- means[1] - b*means[2]
-    var.a    <- var.res/n + var.b*means[2]^2
-    t      <- (a - test.value)/sqrt(var.a)
-    pvalue <- 2*pt( -abs(t), res.df )
+    var.a    <- var.res/n*r.factor2 + var.b*means[2]^2*r.factor1
+    t        <- (a - test.value)/sqrt(var.a)
+    pvalue   <- 2*pt( -abs(t), res.df )
 
-    if ( is.null(data)==FALSE )
-    {
-        detach(data)
-    }
+#     if ( is.null(data)==FALSE )
+#     {
+#         detach(data)
+#     }
 
     list( t=t, a=a, p=pvalue, a.ci=c( a-sqrt(var.a*fcrit), a+sqrt(var.a*fcrit) ), test.value=test.value )
 }
